pub struct LicenseList {
pub license_list_version: String,
pub licenses: Vec<License>,
pub exceptions: Vec<Exception>,
pub release_date: String,
}Fields
license_list_version: Stringlicenses: Vec<License>exceptions: Vec<Exception>release_date: StringImplementations
Sourceimpl LicenseList
impl LicenseList
Sourcepub fn from_github(version: Option<&str>) -> Result<Self, Error>
pub fn from_github(version: Option<&str>) -> Result<Self, Error>
Get LicenseList from GitHub. Specify version as Some("v3.14") or use None for the
latest version.
Errors
Returns [SpdxError] if there is a problem with retrieving the license list from GitHub
or if deserializing the data fails.
pub fn includes_license(&self, spdx_id: &str) -> bool
pub fn includes_exception(&self, exception_id: &str) -> bool
Sourcepub fn is_valid_license(&self, expression: &str) -> bool
pub fn is_valid_license(&self, expression: &str) -> bool
Return true if the input expression is a license on the SPDX license list, a LicenseRef
license, a DocumentRef license, NONE or NOASSERTION.